@@ -36,6 +36,7 @@ from masterdata.models import TimeSheetStatistic
 from masterdata.models import TimeSheetItem
 import calendar
 from random import choice, randint
+import json
 
 class Command(BaseCommand):
     help = _('Személyre szabott törzsadatok generálása.')
@@ -151,10 +152,10 @@ class Command(BaseCommand):
         self.create_uniform_booking_classification_system()
 
         self.stdout.write("Adatlapok generálása ... %s" % self.style.SUCCESS("OK"))
-        self.generate_persons(firstnames=self.FEMALE_FIRST_NAMES, amount=10)
+        self.generate_persons(firstnames=self.FEMALE_FIRST_NAMES, amount=30)
         self.generate_persons(firstnames=self.MALE_FIRST_NAMES, amount=20)
-        self.generate_individuals()
-        self.generate_organizations()
+        self.generate_individuals(amount=15)
+        self.generate_organizations(amount=7)
 
         self.stdout.write("Adatok generálása ... %s" % self.style.SUCCESS("OK"))
         self.log_pauses()
@@ -660,10 +661,22 @@ class Command(BaseCommand):
         for index in range(0, amount):
             year = randint(1920, 2020)
             month = randint(1, 12)
-            day = randint(*calendar.monthrange(year, month)) % 28
+            day = randint(*calendar.monthrange(year, month)) % 27 + 1
             city = choice(self.LOCATIONS)
             street = choice(self.STREETS)
             street_number = randint(1, 200)
+
+            self.stdout.write('Generate new person {data} ...'.format(
+                data = self.style.WARNING(json.dumps(dict(
+                    birth_year = year,
+                    birth_month = month,
+                    birth_day = day,
+                    birt_city = city,
+                    birt_street = street,
+                    birt_street_number = street_number,
+                )))
+            ))
+
             address = Address(raw='{street} utca {street_number}, {city}, Hungary'.format(
                 city=city,
                 street=street,
@@ -692,54 +705,6 @@ class Command(BaseCommand):
 
             )
 
-    # def generate_persons(self):
-    #     """
-    #     Példa személyi addatlapok generálása
-    #     :return:
-    #     """
-
-    #
-    #     address = Address.objects.create(street_number=11,route='Kócsag')
-    #
-    #     self.ofelia_bartok = Person.objects.create(
-    #         gender=gender_female,
-    #         birthdate=datetime(year=1957, month=5, day=19),
-    #         birthplace="Csengele",
-    #         name_of_mother="Karczag Tímea",
-    #         first_name="Ofélia",
-    #         last_name="Bartók",
-    #         permanent_address=address,
-    #         nationality='hu',
-    #         inland_resident=True,
-    #         tax_number='0011344'
-    #     )
-    #
-    #     self.manfred_csele = Person.objects.create(
-    #         gender=gender_male,
-    #         birthdate=datetime(year=1980, month=6, day=11),
-    #         birthplace="Szeged",
-    #         name_of_mother="Boros Katalin",
-    #         first_name="Manfréd",
-    #         last_name="Csele",
-    #         permanent_address=address,
-    #         nationality='hu',
-    #         inland_resident=True,
-    #         tax_number='0011344'
-    #     )
-    #
-    #     self.csanad_bornemissza = Person.objects.create(
-    #         gender=gender_male,
-    #         birthdate=datetime(year=1933, month=3, day=23),
-    #         birthplace="Budapest",
-    #         name_of_mother="Varnusz Titánia",
-    #         first_name="Csanád",
-    #         last_name="Bornemissza",
-    #         permanent_address=address,
-    #         nationality='hu',
-    #         inland_resident=True,
-    #         tax_number='0011344'
-    #     )
-
     def generate_organizations(self, amount=15):
         """
         Példa társas vállakozások generálása
